package VMOMI::HostActiveDirectoryAuthenticationCertificateDigest;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
